@@ -1,3 +1,5 @@
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       PROGRAM IFAL01
 
@@ -12,13 +14,19 @@
 
       WRITE(*,'(A,10I6)') ' LIST OF IX : ',IX
       WRITE(*,'(A)') ' *** OPTION LMISS = .FALSE.'
-      WRITE(*,'(A,I6)') ' *** IMAX = ',IMAX(IX,N,1)
-      WRITE(*,'(A,I6)') ' *** IMIN = ',IMIN(IX,N,1)
-      WRITE(*,'(A,I6)') ' *** ISUM = ',ISUM(IX,N,1)
+      JIMAX=IMAX(IX,N,1)
+      WRITE(*,'(A,I6)') ' *** IMAX = ',JIMAX
+      JIMIN=IMIN(IX,N,1)
+      WRITE(*,'(A,I6)') ' *** IMIN = ',JIMIN
+      JISUM=ISUM(IX,N,1)
+      WRITE(*,'(A,I6)') ' *** ISUM = ',JISUM
       CALL GLLSET('LMISS',.TRUE.)
       WRITE(*,'(A)') ' *** OPTION LMISS = .TRUE.'
-      WRITE(*,'(A,I6)') ' *** IMAX = ',IMAX(IX,N,1)
-      WRITE(*,'(A,I6)') ' *** IMIN = ',IMIN(IX,N,1)
-      WRITE(*,'(A,I6)') ' *** ISUM = ',ISUM(IX,N,1)
+      JIMAX=IMAX(IX,N,1)
+      WRITE(*,'(A,I6)') ' *** IMAX = ',JIMAX
+      JIMIN=IMIN(IX,N,1)
+      WRITE(*,'(A,I6)') ' *** IMIN = ',JIMIN
+      JISUM=ISUM(IX,N,1)
+      WRITE(*,'(A,I6)') ' *** ISUM = ',JISUM
 
       END
