@@ -9,13 +9,10 @@
 
       REAL      XBOX(NP), YBOX(NP)
       CHARACTER CHR*5
-      LOGICAL   LCLCNV
 
       DATA      XBOX/ 0., 1., 1., 0. /
       DATA      YBOX/ 0., 0., 1., 1. /
 
-      CALL SGLSET('LCLCNV',.FALSE.)
-
       WRITE(*,*) ' WORKSTATION ID (I) ? ; '
       CALL SGPWSN
       READ (*,*) IWS
@@ -46,6 +43,11 @@
         CALL SGSVPT( X1, X2, Y1, Y2 )
         CALL SGSTRF
 
+        CALL SGIGET('IBGCLI',IBC)
+        IF(ITPAT.EQ.999)THEN
+          ITPAT=IBC*1000 + 999
+        ENDIF
+
         CALL SLPVPR( 1 )
         CALL SGSTNP( ITPAT )
         CALL SGTNU( NP, XBOX, YBOX )
