@@ -35,9 +35,9 @@
 *------------------------------------------------------------------------
       ENTRY SGQCL(NUM,NR,NG,NB)
 
-      NR=IR(NUM)
-      NG=IG(NUM)
-      NB=IB(NUM)
+      NR=IR(NUM+1)
+      NG=IG(NUM+1)
+      NB=IB(NUM+1)
 
       RETURN
 
