@@ -1,4 +1,6 @@
+#ifndef WINDOWS
 #include <X11/Xlib.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include "../../../config.h"
@@ -8,9 +10,11 @@
 #ifdef HAVE_GTK_H
   #include <gtk/gtk.h>
   #include <gdk/gdkkeysyms.h>
-
+#ifdef WINDOWS
+  #include <gdk/gdkwindow.h>
+#else
   #include <gdk/gdkx.h>
-
+#endif
 #ifdef HAVE_GDK_IMLIB_H
   #include <gdk_imlib.h>
   #define DUMP_IMAGE 1
@@ -64,6 +68,8 @@ static int lfcmod = FALSE;
 static int lfirst = TRUE;
 static int ltfrst = TRUE;
 
+static int laltz = FALSE;
+
 static GdkGC *gc;
 static GdkGC *gct;
 static GtkWidget *window = NULL;
@@ -76,6 +82,7 @@ static int wnd;
 
 #ifdef DUMP_IMAGE
 static char imgfmt[8];
+static DCL_REAL imgcmp;
 #endif
 
 static GdkColor cx[MAXCLI];
@@ -83,7 +90,7 @@ static GdkColor cx[MAXCLI];
 static int ifunc, next;
 static int dumpz = FALSE;
 
-/*------------------------- GDK  ------------------------*/
+/*------------------------- GDK 設定 ------------------------*/
 
 void zgupdate(void)
 {
@@ -95,6 +102,7 @@ void zgupdate(void)
     update_rect.height = drawing_area->allocation.height;
 
     gtk_widget_draw(drawing_area, &update_rect);
+
 }
 
 void zgsdrw_(GtkWidget *d)
@@ -285,9 +293,9 @@ static void zgbmcv(int *nx, int *ny, char bmline[], char bitmap[])
 
 /*------------------------- device ------------------------*/
 void zgdopn_(DCL_INT *width, DCL_INT *height, DCL_INT *iposx, DCL_INT *iposy, 
-             DCL_INT *lwait, DCL_INT *lwait0, DCL_INT *lwait1, DCL_INT *lkey, 
-             DCL_INT *ldump, DCL_INT *lwnd, DCL_INT *lfgbg,
-	     char cimgfmt[], char clrmap[], char cbmmap[], char file[], char title[])
+             DCL_INT *lwait, DCL_INT *lwait0, DCL_INT *lwait1, DCL_INT *lalt,
+             DCL_INT *lkey, DCL_INT *ldump, DCL_INT *lwnd, DCL_INT *lfgbg,
+	     char cimgfmt[], DCL_REAL *rimgcmp, char clrmap[], char cbmmap[], char file[], char title[])
 {
   void cfnchr();
 
@@ -313,10 +321,13 @@ void zgdopn_(DCL_INT *width, DCL_INT *height, DCL_INT *iposx, DCL_INT *iposy,
   key       = *lkey;
   dump      = *ldump;
   fgbg      = *lfgbg;
+  laltz     = *lalt;
 
 #ifdef DUMP_IMAGE
   wnd       = *lwnd;
   cfnchr(imgfmt, cimgfmt, 7);
+  imgcmp = *rimgcmp;
+
   if (!wnd) {
     wait_np = FALSE;
     wait_op = FALSE;
@@ -511,6 +522,10 @@ void zgpcls_(void)
 
   char cout[64];
 
+  char* opt_key[2];
+  char* opt_val[2];
+
+  char cnum[4];
 
   if (ldclonly) {
 
@@ -530,14 +545,31 @@ void zgpcls_(void)
 
 #ifdef HAVE_GDK_PIXBUF_H
       sprintf (cout, "%s_%03d.%s", dmpfile, page, imgfmt);
-      if (!gdk_pixbuf_save(gdk_pixbuf_get_from_drawable(
+      opt_key[0] = NULL;
+      opt_key[1] = NULL;
+      if (imgcmp>=0.0 && imgcmp<=1.0) {
+	if (strcmp(imgfmt, "png")==0) {
+	  opt_key[0] = "compression";
+          sprintf(cnum, "%d", (int)(imgcmp*9));
+	  opt_val[0] = cnum;
+	} else if (strcmp(imgfmt, "jpeg")==0) {
+	  opt_key[0] = "quality";
+	  sprintf(cnum, "%d", (int)((1-imgcmp)*100));
+	  opt_val[0] = cnum;
+	}
+      } else if (imgcmp>1.0) {
+	fprintf(stderr, " *** Error in zgdopn : ");
+	fprintf(stderr,
+		"Image compression must be 0-1.\n");
+      }
+      if (!gdk_pixbuf_savev(gdk_pixbuf_get_from_drawable(
 							NULL,
 							pixmap,
 							NULL,
 							0, 0,
 							0, 0,
 							wsxwd, wsywd),
-			   cout, imgfmt, NULL, NULL) ) {
+			   cout, imgfmt, opt_key, opt_val, NULL) ) {
 	fprintf(stderr, " *** Error in zgdopn : ");
 	fprintf(stderr,
 		"Image format (\"%s\") is not supported.\n", imgfmt);
@@ -575,6 +607,7 @@ void zgoopn_(char *objname, char *comment)
 void zgocls_(char *objname)
 {
 #ifdef HAVE_GTK_H
+  if(!laltz) zgupdate();
 
   /* for long-type message? */
 #endif
@@ -648,11 +681,11 @@ void zggplt_(DCL_REAL *wx, DCL_REAL *wy)
   zgfint_(&rwxold, &rwyold, &iwxold, &iwyold);
   zgfint_( wx,      wy,     &iwx,    &iwy   );
 
-  if (iwxold == iwx && iwyold == iwy)
+  if (iwxold == iwx && iwyold == iwy){
     gdk_draw_point(pixmap, gc, (int) iwx, (int) iwy);
-  else
+  }else{
     gdk_draw_line(pixmap, gc, (int) iwxold, (int) iwyold, (int) iwx, (int) iwy);
-
+  }
   rwxold = *wx;
   rwyold = *wy;
 #endif
@@ -961,6 +994,69 @@ void zgiclr_(DCL_INT *image,DCL_INT *nlen){
 
 
 
+void zgclini_(char clrmap[], DCL_INT *lfgbg){
 
+  void cfnchr();
+
+  char c[80],cmapz[80];
+  FILE *stream;
+  int ncolor,n,m,fscanret;
+  guint16 rx[MAXCLI], gx[MAXCLI], bx[MAXCLI], rx1, gx1, bx1;
+ 
+  GdkVisual *vis;
+  GdkColormap *cmap;
+
+  /* read colormap file */
+
+  cfnchr(cmapz, clrmap, 79);
+
+  if ((stream = fopen(cmapz, "r")) == NULL) {
+    fprintf(stderr, "*** Error in zgdopn : ");
+    fprintf(stderr,
+	    "Allocation failed for colormap (%s).\n", cmapz);
+    exit (1);
+  }
+
+  fscanret=fscanf(stream, "%d : %s", &ncolor, c);
+  for (n = 0; n < ncolor; n++)
+    fscanret=fscanf(stream, "%6hd%6hd%6hd : %s", &rx[n], &gx[n], &bx[n], c);
+  fclose(stream);
+
+  if (fgbg) {
+    rx1 = rx[0];
+    gx1 = gx[0];
+    bx1 = bx[0];
+    rx[0] = rx[1];
+    gx[0] = gx[1];
+    bx[0] = bx[1];
+    rx[1] = rx1;
+    gx[1] = gx1;
+    bx[1] = bx1;
+	}
+
+  /* set colormap */
+
+  vis = gtk_widget_get_visual(drawing_area);
+
+  lclatrz = (vis->type != GDK_VISUAL_STATIC_GRAY);
+
+  if (lclatrz) {
+
+    cmap = gtk_widget_get_colormap(drawing_area);
+
+    for (n = 0; n < MAXCLI; n++) {
+
+      m = n % ncolor;
+
+      cx[n].red   = rx[m];
+      cx[n].green = gx[m];
+      cx[n].blue  = bx[m];
+
+      if (!gdk_colormap_alloc_color(cmap, &cx[n], FALSE, FALSE))
+	break;
+    }
+   }
+
+}
 
 
